##  Planning Transformations for Suggested SAP Solutions
Suggested SAP solutions are specific to level 3 business capabilities in the reference catalog. You can create transformation items from these suggested solutions in the Transformations tab of a level 3 business capabiltiy fact sheet. You can also create transformation items in bulk from level 2 fact sheets for multiple level 3 child fact sheets.
To plan a transformation for a suggested SAP solution, follow these steps:
  1. Go to the Transformations tab of the business capability fact sheet.
  2. Choose the suggested option(s) based on whether you are planning from a level 3 or level 2 business capability fact sheet:
    1. From a level 3 business capability fact sheet:
      1. Choose the option relevant to you by clicking Plan Transformations for that option.
    2. From a level 2 business capability fact sheet:
      1. Choose one or more options for multiple level 3 business capability fact sheets listed in the transformations tab.
      2. Click Plan Transformations at the top right.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob8c2b151ba864dfd8373567ae3cd32e5_LowRes.png)
      3. If you have selected options for the level 3 business capabilities that are not yet imported or linked to the reference catalog, you are prompted to import the missing ones. Click Import and Plan Transformations to proceed.
  3. A suggested SAP solution may include one or several suggested applications. Select the applications you want to roll out for the business capability. In addition to selecting existing fact sheets, you can create new fact sheets by clicking Add a fact sheet.
     * If that application fact sheet already exists in your workspace, a transformation of type ‘Rollout Application’ is created.
     * If it is a new application fact sheet, a transformation of type ‘Introduce a New Application’ is created. To learn about various transformation types, see [Transformation Templates](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275e2dd37a441014984cebdd0f799345__transformation_templates).
For SAP S/4HANA applications, you can decide whether to plan your transformations at the level 1 SAP S/4HANA or at the level 2 line of business application. For modeling guidelines, refer to [SAP S/4HANA Modeling Best Practices and Guidelines](https://help.sap.com/docs/leanix/ea/modeling-sap-s4hana?locale=en-US&state=PRODUCTION&version=CLOUD#loio275b5c467a441014b33ebd9a843a9ccb__sap_s_4hana_modeling_best_practices_and_guidelines).
![Screen for selecting new applications to roll out for a business capability.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio9a39f6dd1b804c5f9f0297f774179a85_LowRes.png)
Selecting and Adding Application Fact Sheets for the Suggested Solution
  4. After selecting the applications, click Next.
  5. Select an existing initiative or create a new one to which the transformations should belong. Optionally, set the initiative subtype and link a parent fact sheet if the rollout is part of a larger initiative.
  6. Select or create a milestone and set a target date for rollout/introduction. This date is needed to visualize impacts in reports. If the actual date is not known yet, use a placeholder date and update it later.
  7. Click Create Transformations.
![Creating Initiative and Setting Milestones](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27553e917a4410149a21c65efeb13da4_LowRes.png)
Creating Initiative and Setting Milestones


You can add more details later by editing the initiative, such as specifying organizations or setting predecessors, etc. The created transformations are in the Planned Transformations section below, within the Transformations tab of the fact sheet.
In the next steps, you can gain clarity by visualizing your target architecture, comparing transformation scenarios, and monitoring progress through reports and roadmaps. To learn more, see [Reports and Roadmaps](https://help.sap.com/docs/leanix/ea/reports-and-roadmaps?locale=en-US&state=PRODUCTION&version=CLOUD "Reports offer valuable insights throughout—from gaining clarity and visualizing target architecture to comparing scenarios, planning roadmaps, and monitoring progress.").
YesNo
Send
